#[non_exhaustive]#[repr(u8)]pub enum Outcome {
Success = 0,
Failure = 1,
Denied = 2,
Error = 3,
}Expand description
Outcome of an audited action (the “result”).
#[non_exhaustive] so additional outcomes may be added without a major
version bump.
Example
use audit_trail::Outcome;
assert_eq!(Outcome::Success.as_u8(), 0);Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Success = 0
The action completed successfully.
Failure = 1
The action was attempted and failed for an operational reason.
Denied = 2
The action was denied by policy or authorization.
Error = 3
The action errored due to an unexpected condition.
Implementations